==> servicecatalog-model-6.8.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterObjectReferenceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterObjectReferenceFluent<A extends ClusterObjectReferenceFluent<A>> extends BaseFluent<A>{
  public ClusterObjectReferenceFluent() {
  }
  public ClusterObjectReferenceFluent(ClusterObjectReference instance) {
    instance = (instance != null ? instance : new ClusterObjectReference());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
    }
  }
  private String name;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterObjectReferenceFluent that = (ClusterObjectReferenceFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterObjectReferenceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterObjectReferenceFluent<A extends ClusterObjectReferenceFluent<A>> extends BaseFluent<A>{
  public ClusterObjectReferenceFluent() {
  }
  
  public ClusterObjectReferenceFluent(ClusterObjectReference instance) {
    this.copyInstance(instance);
  }
  private String name;
  
  protected void copyInstance(ClusterObjectReference instance) {
    instance = (instance != null ? instance : new ClusterObjectReference());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withName(instance.getName());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterObjectReferenceFluent that = (ClusterObjectReferenceFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  

}
